@@ -15,15 +15,15 @@ sub _refresh_search_flags {
 	my $attr = _attributes();
 	my $flags = 0;
 
-	$flags |= Wx::wxSTC_FIND_MATCHCASE
+	$flags |= &Wx::wxSTC_FIND_MATCHCASE
 		if defined $attr->{match_case} and $attr->{match_case};
 	if ( defined $attr->{match_whole_word} and $attr->{match_whole_word} ) {
-		$flags |= Wx::wxSTC_FIND_WHOLEWORD
+		$flags |= &Wx::wxSTC_FIND_WHOLEWORD
 	} else {
-		$flags |= Wx::wxSTC_FIND_WORDSTART
+		$flags |= &Wx::wxSTC_FIND_WORDSTART
 			if $attr->{match_word_begin} and $attr->{match_word_begin};
 	}
-	$flags |= Wx::wxSTC_FIND_REGEXP
+	$flags |= &Wx::wxSTC_FIND_REGEXP
 		if defined $attr->{match_regex} and $attr->{match_regex};
 	$Kephra::temp{search}{flags} = $flags;
 }
@@ -246,17 +246,17 @@ sub first_increment {
 #sub next_increment {}
 # find related menu calls
 sub find_all{
-#Kephra::Dialog::msg_box(undef, Wx::wxUNICODE(), '');
+#Kephra::Dialog::msg_box(undef, &Wx::wxUNICODE(), '');
 	my $ep = Kephra::App::EditPanel::_ref();
 	if ( _exist_find_item() ) {
 		my $search_result = _find_first();
 		my ($sel_start, $sel_end);
 		#Kephra::Dialog::msg_box(undef, , '');
-		#$ep->IndicatorSetStyle(0, Wx::wxSTC_INDIC_TT );
-		#$ep->IndicatorSetForeground(0, Wx::Colour->new(0xff, 0x00, 0x00));
-		$ep->IndicatorSetStyle(1, Wx::wxSTC_INDIC_TT );
-		$ep->IndicatorSetForeground(1, Wx::Colour->new(0xff, 0x00, 0x00));
-		# ^= Wx::wxSTC_INDIC_STRIKE;
+		#$ep->IndicatorSetStyle(0, &Wx::wxSTC_INDIC_TT );
+		#$ep->IndicatorSetForeground(0, &Wx::Colour->new(0xff, 0x00, 0x00));
+		$ep->IndicatorSetStyle(1, &Wx::wxSTC_INDIC_TT );
+		$ep->IndicatorSetForeground(1, &Wx::Colour->new(0xff, 0x00, 0x00));
+		# ^= &Wx::wxSTC_INDIC_STRIKE;
 		$ep->SetSelection(0,0);
 		return 0 if $search_result == -1;
 		while ($search_result > -1){
@@ -611,7 +611,7 @@ sub replace_confirm {
 		my $len  = _exist_find_item();
 		my $sel_begin = $ep->GetSelectionStart;
 		my $sel_end   = $ep->GetSelectionEnd;
-		my $answer    = Wx::wxYES;
+		my $answer    = &Wx::wxYES;
 		my $menu_call = shift;
 
 		set_range('selection')
@@ -627,7 +627,7 @@ sub replace_confirm {
 			my $begin_doc = Kephra::Document::Data::current_nr();
 			do {
 				{
-					next if $answer == Wx::wxCANCEL;
+					next if $answer == &Wx::wxCANCEL;
 					Kephra::Edit::_save_positions();
 					$answer = sniff_selection
 						( $ep, 0, $ep->GetTextLength, $len, $line );
@@ -648,8 +648,8 @@ sub replace_confirm {
 			Kephra::Edit::_center_caret();
 			$answer = Kephra::Dialog::get_confirm_3
 				(undef, $l10n->{text}, $l10n->{title}, 100, 100);
-			last if $answer == Wx::wxCANCEL;
-			if ($answer == Wx::wxYES) {replace_selection()}
+			last if $answer == &Wx::wxCANCEL;
+			if ($answer == &Wx::wxYES) {replace_selection()}
 			else                    {$ep->SetCurrentPos( $ep->GetCurrentPos + 1 )}
 		}
 		$ep->EndUndoAction;
@@ -668,7 +668,6 @@ our $VERSION = '0.04';
 
 use strict;
 use base qw(Wx::TextDropTarget);
-use Wx;
 use Wx::DND;
 
 sub new {
